pub enum Error {
Incomplete,
Protocol,
Hpack,
BufferTooSmall,
FrameTooLarge,
GoAway,
StreamReset,
TooManyStreams,
}Variants
Incomplete
More bytes are needed before this can be decoded.
Protocol
The peer sent something that is not valid HTTP/2.
Hpack
A header block could not be decoded. Fatal for the connection: HPACK state cannot be resynchronised.
BufferTooSmall
A fixed buffer was too small.
FrameTooLarge
A frame larger than the negotiated maximum.
GoAway
The peer closed the connection with GOAWAY.
StreamReset
The peer reset the stream.
TooManyStreams
More concurrent streams than this client supports.